package com.persagy.adm.server.custom.controller;


import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.persagy.adm.server.custom.dto.CadFiles;
import com.persagy.adm.server.custom.entity.CadFileQueryParam;
import com.persagy.adm.server.custom.entity.db.AdmCad;
import com.persagy.adm.server.custom.enums.MajorEnum;
import com.persagy.adm.server.custom.service.IAdmCadService;
import com.persagy.dmp.common.context.AppContext;
import com.persagy.dmp.common.model.response.CommonResult;
import com.persagy.dmp.common.utils.ResultHelper;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.List;

/**
 * ADM文件服务
 * @author yanguofeng
 * @since 2022-01-10
 */
@RestController
@RequestMapping("/adm/adm-file")
public class AdmFileController {

    @Autowired
    IAdmCadService iAdmCadService;

    /**
     * CAD文件查询接口
     */

    @PostMapping("/queryCadFiles")
    public CommonResult<List<AdmCad>> queryCadFiles(@RequestBody CadFileQueryParam queryParam){
        AppContext context = AppContext.getContext();
        Wrapper<AdmCad> eq = new LambdaQueryWrapper<AdmCad>()
                .eq(StringUtils.isNotBlank(context.getGroupCode()), AdmCad::getGroupCode, context.getProjectId())
                .eq(StringUtils.isNotBlank(context.getProjectId()), AdmCad::getProjectId, context.getProjectId())
                .eq(StringUtils.isNotBlank(queryParam.getBuildingId()),AdmCad::getBuildingId,queryParam.getBuildingId())
                .eq(StringUtils.isNotBlank(queryParam.getFloorId()),AdmCad::getFloorId,queryParam.getFloorId())
                .eq(StringUtils.isNotBlank(queryParam.getFileKey()),AdmCad::getFileKey,queryParam.getFileKey())
                .eq(StringUtils.isNotBlank(queryParam.getMajorCode()),AdmCad::getMajorCode,queryParam.getMajorCode());
        return ResultHelper.multi(iAdmCadService.list(eq));
    }

    /**
     * 保存CAD文件信息
     */
    @PostMapping("/saveCadFileInfo")
    public CommonResult<Void> saveCadFileInfo(@RequestBody @Validated CadFiles cadFiles){
        List<AdmCad> admFiles = new ArrayList<>();
        AppContext context = AppContext.getContext();
        cadFiles.getFiles().forEach(file -> {
            AdmCad admCad = new AdmCad();
            admCad.setGroupCode(context.getGroupCode());
            admCad.setProjectId(context.getProjectId());
            admCad.setBuildingId(cadFiles.getBuildingId());
            admCad.setFloorId(cadFiles.getFloorId());
            admCad.setMajorCode(cadFiles.getMajorCode());
            admCad.setMajorName(MajorEnum.getComment(cadFiles.getMajorCode()));
            admCad.setCheckStatus(false);
            admCad.setFileKey(file.getFileKey());
            admCad.setFileName(file.getFileName());
            admFiles.add(admCad);
        });
        iAdmCadService.saveOrUpdateBatch(admFiles);
        return ResultHelper.success();
    }

    /**
     * 删除CAD文件信息
     * @param id 文件信息表主键ID
     */
    @PostMapping("/delete")
    public CommonResult<Void> delete(@RequestParam("id") String id){
        iAdmCadService.removeById(id);
        return ResultHelper.success();
    }
}
